==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/no/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'accessory_name' => 'Navn tilbehør:',
    'additional_notes' => 'Flere notater:',
    'admin_has_created' => 'En administrator har opprettet en konto for deg på :web nettsted.',
    'asset' => 'Eiendel:',
    'asset_name' => 'Navn:',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke:',
    'assigned_to' => 'Tilordnet til',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt:',
    'checkin_date' => 'Innsjekkdato:',
    'checkout_date' => 'Utsjekkdato:',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Nåværende antall',
    'Days' => 'Dager',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet innsjekkdato:',
    'expires' => 'Utløper',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler.',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser.',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'item' => 'Enhet:',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'login' => 'Logg inn:',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'En ny enhet har blitt sjekket ut under ditt navn, detaljer nedenfor.',
    'password' => 'Passord:',
    'password_reset' => 'Tilbakestill passord',

    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les bruksbetingelsene nedenfor, og klikk på lenken på bunnen for å bekrefte at du har lest og er enig med betingelsene, og har mottatt eiendelen.',
    'requested' => 'Forespurt:',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'serial' => 'Serienummer',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'assets_warrantee_alert' => ':count eiendel har garanti som utløper de neste :threshold dagene.|:count eiendeler har garanti som utløper de neste :threshold dagene.',
    'license_expiring_alert' => ':count lisens utløper de neste :threshold dagene.|:count lisenser utløper de neste :threshold dagene.',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_credentials' => 'Din Snipe-IT konto',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/no/mail.php <==
<?php

return [
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'accessory_name' => 'Navn tilbehør:',
    'additional_notes' => 'Flere notater:',
    'admin_has_created' => 'En administrator har opprettet en konto for deg på :web nettsted.',
    'asset' => 'Eiendel:',
    'asset_name' => 'Navn:',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke',
    'assigned_to' => 'Tilordnet til',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt:',
    'checkin_date' => 'Innsjekkdato:',
    'checkout_date' => 'Utsjekkdato:',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'Confirm_Asset_Checkin' => 'Bekreft innsjekk av eiendel',
    'Confirm_Accessory_Checkin' => 'Bekreft innsjekk av tilbehør',
    'Confirm_accessory_delivery' => 'Bekreft levering av tilbehør',
    'Confirm_license_delivery' => 'Bekreft levering av lisens',
    'Confirm_asset_delivery' => 'Bekreft levering av eiendel',
    'Confirm_consumable_delivery' => 'Bekreft levering av forbruksvare',
    'current_QTY' => 'Nåværende antall',
    'Days' => 'Dager',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet innsjekkdato:',
    'expires' => 'Utløper',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler.',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser.',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'item' => 'Enhet:',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'login' => 'Logg inn:',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'En ny enhet har blitt sjekket ut under ditt navn, detaljer nedenfor.',
    'password' => 'Passord:',
    'password_reset' => 'Tilbakestill passord',

    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les bruksbetingelsene nedenfor, og klikk på lenken på bunnen for å bekrefte at du har lest og er enig med betingelsene, og har mottatt eiendelen.',
    'requested' => 'Forespurt:',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'serial' => 'Serienummer',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'assets_warrantee_alert' => 'En eiendel har garanti som utløper innenfor de neste :treshold dagene.|:count eiendeler har garanti som utløper innenfor de neste :tershold dagene.',
    'license_expiring_alert' => ':count lisens utløper de neste :threshold dagene.|:count lisenser utløper de neste :threshold dagene.',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => ':count eiendel har revisjonsfrist innen :treshold dager.|:count eiendeler har revisjonsfrist innen :threshold dager.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_credentials' => 'Din Snipe-IT konto',
    'Accessory_Checkin_Notification' => 'Tilbehør sjekket inn',
    'Asset_Checkin_Notification' => 'Eiendel sjekket inn',
    'License_Checkin_Notification' => 'Lisens sjekket inn',
    'Expected_Checkin_Report' => 'Rapport over forventet innsjekking av eiendeler',
    'Expected_Checkin_Notification' => 'Påminnelse: Innsjekkingsfrist for :name nærmer seg',
    'Expected_Checkin_Date' => 'En enhet som er sjekket ut til deg skal leveres tilbake den :date',
    'your_assets' => 'Vis dine eiendeler',
];
